==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/db/d22/openttd_8h.js <==
var openttd_8h =
[
    [ "PauseModeByte", "db/d22/openttd_8h.html#ad5549e4c847bfd05a09a0e8d43ce7eb7", null ],
    [ "DisplayOptions", "db/d22/openttd_8h.html#ad2e3dcfe27167d96670a4b56e35c7d69", [
      [ "DO_SHOW_TOWN_NAMES", "db/d22/openttd_8h.html#ad2e3dcfe27167d96670a4b56e35c7d69a1917cd15e4a31f03a1b2dc0a8ce52383", null ],
      [ "DO_SHOW_STATION_NAMES", "db/d22/openttd_8h.html#ad2e3dcfe27167d96670a4b56e35c7d69adec0b630510636fb1a6a2836d8c68b99", null ],
      [ "DO_SHOW_SIGNS", "db/d22/openttd_8h.html#ad2e3dcfe27167d96670a4b56e35c7d69a83b041b69c45d69c390cd551e1ba939b", null ],
      [ "DO_FULL_ANIMATION", "db/d22/openttd_8h.html#ad2e3dcfe27167d96670a4b56e35c7d69af4d1c97502b21dc5111549a7fa433615", null ],
      [ "DO_FULL_DETAIL", "db/d22/openttd_8h.html#ad2e3dcfe27167d96670a4b56e35c7d69a584158881512736832f427bc03584af6", null ],
      [ "DO_SHOW_WAYPOINT_NAMES", "db/d22/openttd_8h.html#ad2e3dcfe27167d96670a4b56e35c7d69a8a9290c7be9707183898d07507298b60", null ],
      [ "DO_SHOW_COMPETITOR_SIGNS", "db/d22/openttd_8h.html#ad2e3dcfe27167d96670a4b56e35c7d69a294c53f927554be7f4c45a627e69ad79", null ]
    ] ],
    [ "GameMode", "db/d22/openttd_8h.html#aaf5ef5a17b53e9997c837b07015589de", [
      [ "GM_MENU", "db/d22/openttd_8h.html#aaf5ef5a17b53e9997c837b07015589deaf7217683fbc5fe556d084964322a74e2", null ],
      [ "GM_NORMAL", "db/d22/openttd_8h.html#aaf5ef5a17b53e9997c837b07015589dea93eef8070f7970c007307727ecc4a11a", null ],
      [ "GM_EDITOR", "db/d22/openttd_8h.html#aaf5ef5a17b53e9997c837b07015589dea43a0634950061d92e5fcbdc67e516a71", null ],
      [ "GM_BOOTSTRAP", "db/d22/openttd_8h.html#aaf5ef5a17b53e9997c837b07015589dea81d53de122454a31fad41054a5381310", null ]
    ] ],
    [ "PauseMode", "db/d22/openttd_8h.html#a843f669f31e808d7294abd23cea378bf", [
      [ "PM_UNPAUSED", "db/d22/openttd_8h.html#a843f669f31e808d7294abd23cea378bfa1ba4ee9f5bd31eaf5094d093fc65e016", null ],
      [ "PM_PAUSED_NORMAL", "db/d22/openttd_8h.html#a843f669f31e808d7294abd23cea378bfad562adaccc7df8ce4db197609aa07df3", null ],
      [ "PM_PAUSED_SAVELOAD", "db/d22/openttd_8h.html#a843f669f31e808d7294abd23cea378bfaec2e0f3c6f082a05356e30abc1a9f3f5", null ],
      [ "PM_PAUSED_JOIN", "db/d22/openttd_8h.html#a843f669f31e808d7294abd23cea378bfaabea4224a18772d62c71ff4b685607c5", null ],
      [ "PM_PAUSED_ERROR", "db/d22/openttd_8h.html#a843f669f31e808d7294abd23cea378bfa8a46cd5f8fc1bdc48bae307f4774a011", null ],
      [ "PM_PAUSED_ACTIVE_CLIENTS", "db/d22/openttd_8h.html#a843f669f31e808d7294abd23cea378bfa40a0a40141164aaeda9facb443b72134", null ],
      [ "PM_PAUSED_GAME_SCRIPT", "db/d22/openttd_8h.html#a843f669f31e808d7294abd23cea378bfa9e5182ab143a19901bb2c97d1ed6af9b", null ],
      [ "PMB_PAUSED_NETWORK", "db/d22/openttd_8h.html#a843f669f31e808d7294abd23cea378bfab511435d3684ffac1765d86b3b7a4bae", null ]
    ] ],
    [ "SwitchMode", "db/d22/openttd_8h.html#a38fc848189063403eed9b87dd0efe36c", [
      [ "SM_NONE", "db/d22/openttd_8h.html#a38fc848189063403eed9b87dd0efe36ca73e917286b73a0dd67b0eb8145cc0c7b", null ],
      [ "SM_NEWGAME", "db/d22/openttd_8h.html#a38fc848189063403eed9b87dd0efe36caed15fd016352e3ae08f60f4eefb26b9f", null ],
      [ "SM_RESTARTGAME", "db/d22/openttd_8h.html#a38fc848189063403eed9b87dd0efe36ca753ac84e8518d729595379d2cf63197b", null ],
      [ "SM_EDITOR", "db/d22/openttd_8h.html#a38fc848189063403eed9b87dd0efe36caea4bde2b6b21b563f1c1882e410e6236", null ],
      [ "SM_LOAD_GAME", "db/d22/openttd_8h.html#a38fc848189063403eed9b87dd0efe36cad5dee504597a02540854287ee5218b37", null ],
      [ "SM_MENU", "db/d22/openttd_8h.html#a38fc848189063403eed9b87dd0efe36ca63a1ac7267df4381e173efef271cb856", null ],
      [ "SM_SAVE_GAME", "db/d22/openttd_8h.html#a38fc848189063403eed9b87dd0efe36caa980ffee00afa7cfa766498432803648", null ],
      [ "SM_SAVE_HEIGHTMAP", "db/d22/openttd_8h.html#a38fc848189063403eed9b87dd0efe36ca8f5ef636a8386050ff9220a5831c0944", null ],
      [ "SM_GENRANDLAND", "db/d22/openttd_8h.html#a38fc848189063403eed9b87dd0efe36ca516cbd347e07a97cea496cdca8dcf874", null ],
      [ "SM_LOAD_SCENARIO", "db/d22/openttd_8h.html#a38fc848189063403eed9b87dd0efe36ca3de4d316c475cf9f658380b0f4ecba4e", null ],
      [ "SM_START_HEIGHTMAP", "db/d22/openttd_8h.html#a38fc848189063403eed9b87dd0efe36ca0abd2cb09cbdbc0555e872121658c4d9", null ],
      [ "SM_LOAD_HEIGHTMAP", "db/d22/openttd_8h.html#a38fc848189063403eed9b87dd0efe36ca8fbe4fb5c3350b8a49387d84dca2014d", null ]
    ] ],
    [ "AskExitGame", "db/d22/openttd_8h.html#a9138b66977721e351c731d875481861b", null ],
    [ "AskExitToGameMenu", "db/d22/openttd_8h.html#ac3e52adbdf3aaa9bade13e9953889473", null ],
    [ "HandleExitGameRequest", "db/d22/openttd_8h.html#a49f9e3875ec1b2291054ea045fde8cf6", null ],
    [ "openttd_main", "db/d22/openttd_8h.html#ae6cedfbbe1abfcae0d6a9532e513d847", null ],
    [ "SwitchToMode", "db/d22/openttd_8h.html#adc874554ae96fb91249ef56dcb131ba6", null ],
    [ "_exit_game", "db/d22/openttd_8h.html#a7eb0d14ae569ca0992df5214cd0b249c", null ],
    [ "_game_mode", "db/d22/openttd_8h.html#a5f7525568d0b37fb0b60f52154db6b1b", null ],
    [ "_pause_mode", "db/d22/openttd_8h.html#afdd79e14e419f125b43346bbe5a5b132", null ],
    [ "_switch_mode", "db/d22/openttd_8h.html#aca417dc75c3ef57541db809c4664cf74", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/db/d22/openttd_8h.js <==
var openttd_8h =
[
    [ "DisplayOptions", "db/d22/openttd_8h.html#ad2e3dcfe27167d96670a4b56e35c7d69", [
      [ "DO_SHOW_TOWN_NAMES", "db/d22/openttd_8h.html#ad2e3dcfe27167d96670a4b56e35c7d69a1917cd15e4a31f03a1b2dc0a8ce52383", null ],
      [ "DO_SHOW_STATION_NAMES", "db/d22/openttd_8h.html#ad2e3dcfe27167d96670a4b56e35c7d69adec0b630510636fb1a6a2836d8c68b99", null ],
      [ "DO_SHOW_SIGNS", "db/d22/openttd_8h.html#ad2e3dcfe27167d96670a4b56e35c7d69a83b041b69c45d69c390cd551e1ba939b", null ],
      [ "DO_FULL_ANIMATION", "db/d22/openttd_8h.html#ad2e3dcfe27167d96670a4b56e35c7d69af4d1c97502b21dc5111549a7fa433615", null ],
      [ "DO_FULL_DETAIL", "db/d22/openttd_8h.html#ad2e3dcfe27167d96670a4b56e35c7d69a584158881512736832f427bc03584af6", null ],
      [ "DO_SHOW_WAYPOINT_NAMES", "db/d22/openttd_8h.html#ad2e3dcfe27167d96670a4b56e35c7d69a8a9290c7be9707183898d07507298b60", null ],
      [ "DO_SHOW_COMPETITOR_SIGNS", "db/d22/openttd_8h.html#ad2e3dcfe27167d96670a4b56e35c7d69a294c53f927554be7f4c45a627e69ad79", null ]
    ] ],
    [ "GameMode", "db/d22/openttd_8h.html#aaf5ef5a17b53e9997c837b07015589de", [
      [ "GM_MENU", "db/d22/openttd_8h.html#aaf5ef5a17b53e9997c837b07015589deaf7217683fbc5fe556d084964322a74e2", null ],
      [ "GM_NORMAL", "db/d22/openttd_8h.html#aaf5ef5a17b53e9997c837b07015589dea93eef8070f7970c007307727ecc4a11a", null ],
      [ "GM_EDITOR", "db/d22/openttd_8h.html#aaf5ef5a17b53e9997c837b07015589dea43a0634950061d92e5fcbdc67e516a71", null ],
      [ "GM_BOOTSTRAP", "db/d22/openttd_8h.html#aaf5ef5a17b53e9997c837b07015589dea81d53de122454a31fad41054a5381310", null ]
    ] ],
    [ "PauseMode", "db/d22/openttd_8h.html#aebf8f45f239290b7abb78350d71ca60a", [
      [ "PM_UNPAUSED", "db/d22/openttd_8h.html#aebf8f45f239290b7abb78350d71ca60aa1ba4ee9f5bd31eaf5094d093fc65e016", null ],
      [ "PM_PAUSED_NORMAL", "db/d22/openttd_8h.html#aebf8f45f239290b7abb78350d71ca60aad562adaccc7df8ce4db197609aa07df3", null ],
      [ "PM_PAUSED_SAVELOAD", "db/d22/openttd_8h.html#aebf8f45f239290b7abb78350d71ca60aaec2e0f3c6f082a05356e30abc1a9f3f5", null ],
      [ "PM_PAUSED_JOIN", "db/d22/openttd_8h.html#aebf8f45f239290b7abb78350d71ca60aaabea4224a18772d62c71ff4b685607c5", null ],
      [ "PM_PAUSED_ERROR", "db/d22/openttd_8h.html#aebf8f45f239290b7abb78350d71ca60aa8a46cd5f8fc1bdc48bae307f4774a011", null ],
      [ "PM_PAUSED_ACTIVE_CLIENTS", "db/d22/openttd_8h.html#aebf8f45f239290b7abb78350d71ca60aa40a0a40141164aaeda9facb443b72134", null ],
      [ "PM_PAUSED_GAME_SCRIPT", "db/d22/openttd_8h.html#aebf8f45f239290b7abb78350d71ca60aa9e5182ab143a19901bb2c97d1ed6af9b", null ],
      [ "PM_PAUSED_LINK_GRAPH", "db/d22/openttd_8h.html#aebf8f45f239290b7abb78350d71ca60aacd69b9dc63ec953c629de27257ac55aa", null ],
      [ "PMB_PAUSED_NETWORK", "db/d22/openttd_8h.html#aebf8f45f239290b7abb78350d71ca60aab511435d3684ffac1765d86b3b7a4bae", null ]
    ] ],
    [ "SwitchMode", "db/d22/openttd_8h.html#a38fc848189063403eed9b87dd0efe36c", [
      [ "SM_NONE", "db/d22/openttd_8h.html#a38fc848189063403eed9b87dd0efe36ca73e917286b73a0dd67b0eb8145cc0c7b", null ],
      [ "SM_NEWGAME", "db/d22/openttd_8h.html#a38fc848189063403eed9b87dd0efe36caed15fd016352e3ae08f60f4eefb26b9f", null ],
      [ "SM_RESTARTGAME", "db/d22/openttd_8h.html#a38fc848189063403eed9b87dd0efe36ca753ac84e8518d729595379d2cf63197b", null ],
      [ "SM_RELOADGAME", "db/d22/openttd_8h.html#a38fc848189063403eed9b87dd0efe36ca85d49727e5a343bbc4520ba2cbd78d14", null ],
      [ "SM_EDITOR", "db/d22/openttd_8h.html#a38fc848189063403eed9b87dd0efe36caea4bde2b6b21b563f1c1882e410e6236", null ],
      [ "SM_LOAD_GAME", "db/d22/openttd_8h.html#a38fc848189063403eed9b87dd0efe36cad5dee504597a02540854287ee5218b37", null ],
      [ "SM_MENU", "db/d22/openttd_8h.html#a38fc848189063403eed9b87dd0efe36ca63a1ac7267df4381e173efef271cb856", null ],
      [ "SM_SAVE_GAME", "db/d22/openttd_8h.html#a38fc848189063403eed9b87dd0efe36caa980ffee00afa7cfa766498432803648", null ],
      [ "SM_SAVE_HEIGHTMAP", "db/d22/openttd_8h.html#a38fc848189063403eed9b87dd0efe36ca8f5ef636a8386050ff9220a5831c0944", null ],
      [ "SM_GENRANDLAND", "db/d22/openttd_8h.html#a38fc848189063403eed9b87dd0efe36ca516cbd347e07a97cea496cdca8dcf874", null ],
      [ "SM_LOAD_SCENARIO", "db/d22/openttd_8h.html#a38fc848189063403eed9b87dd0efe36ca3de4d316c475cf9f658380b0f4ecba4e", null ],
      [ "SM_START_HEIGHTMAP", "db/d22/openttd_8h.html#a38fc848189063403eed9b87dd0efe36ca0abd2cb09cbdbc0555e872121658c4d9", null ],
      [ "SM_LOAD_HEIGHTMAP", "db/d22/openttd_8h.html#a38fc848189063403eed9b87dd0efe36ca8fbe4fb5c3350b8a49387d84dca2014d", null ],
      [ "SM_RESTART_HEIGHTMAP", "db/d22/openttd_8h.html#a38fc848189063403eed9b87dd0efe36ca1da1483601c10fd801096a62b33f361d", null ]
    ] ],
    [ "AskExitGame", "db/d22/openttd_8h.html#a9138b66977721e351c731d875481861b", null ],
    [ "AskExitToGameMenu", "db/d22/openttd_8h.html#ac3e52adbdf3aaa9bade13e9953889473", null ],
    [ "HandleExitGameRequest", "db/d22/openttd_8h.html#a49f9e3875ec1b2291054ea045fde8cf6", null ],
    [ "openttd_main", "db/d22/openttd_8h.html#ae6cedfbbe1abfcae0d6a9532e513d847", null ],
    [ "SwitchToMode", "db/d22/openttd_8h.html#adc874554ae96fb91249ef56dcb131ba6", null ],
    [ "_exit_game", "db/d22/openttd_8h.html#a7eb0d14ae569ca0992df5214cd0b249c", null ],
    [ "_game_mode", "db/d22/openttd_8h.html#a5f7525568d0b37fb0b60f52154db6b1b", null ],
    [ "_pause_mode", "db/d22/openttd_8h.html#a1954072478034feb4d6b9cc867ce5f6d", null ],
    [ "_save_config", "db/d22/openttd_8h.html#a6b31e7f0f606cf97512e4a09d1b9f4f9", null ],
    [ "_switch_mode", "db/d22/openttd_8h.html#aca417dc75c3ef57541db809c4664cf74", null ]
];
